Coverage for /media/ldata/code/tendril/tendril/frontend/startup/reset_db.py: 0%

# Coverage for /media/ldata/code/tendril/tendril/frontend/startup/reset_db.py : 0%

## 36 statements 0 run 36 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 | # Copyright (C) 2015 Chintalagiri Shashank # # This file is part of Tendril. # # This program is free software: you can redistribute it and/or modify # it under the terms of the GNU Affero General Public License as published by # the Free Software Foundation, either version 3 of the License, or # (at your option) any later version. # # This program is distributed in the hope that it will be useful, # but WITHOUT ANY WARRANTY; without even the implied warranty of # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the # GNU Affero General Public License for more details. # # You should have received a copy of the GNU Affero General Public License # along with this program. If not, see <http://www.gnu.org/licenses/>. from __future__ import print_function import datetime from tendril.frontend.app import app, db from tendril.frontend.startup.init_app import init_app from tendril.frontend.users.models import User, UserAuth, Role def reset_db(app, db): """ Delete all tables; Create all tables; Populate roles and users. """ # Drop all tables print('Dropping all tables') db.drop_all() # Create all tables print('Creating all tables') db.create_all() # Adding roles print('Adding roles') admin_role = Role(name='admin') db.session.add(admin_role) exec_role = Role(name='exec') db.session.add(exec_role) internal_role = Role(name='internal') db.session.add(internal_role) # Add users print('Adding users') from tendril.utils.config import ADMIN_USERNAME from tendril.utils.config import ADMIN_FULLNAME from tendril.utils.config import ADMIN_EMAIL from tendril.utils.config import ADMIN_PASSWORD user = add_user( app, db, ADMIN_USERNAME, ADMIN_FULLNAME, ADMIN_EMAIL, ADMIN_PASSWORD ) user.roles.append(admin_role) user.roles.append(exec_role) user.roles.append(internal_role) db.session.commit() def add_user(app, db, username, full_name, email, password): """ Create UserAuth and User records. """ user_auth = UserAuth(username=username, password=app.user_manager.hash_password(password)) user = User( active=True, full_name=full_name, email=email, confirmed_at=datetime.datetime.now(), user_auth=user_auth ) db.session.add(user_auth) db.session.add(user) return user # Initialize the app and reset the database if __name__ == "__main__": init_app(app, db) reset_db(app, db)